# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wifi_connection_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1awifi_connection_info.proto\x12\x11insta360.messages"T\n\x12WifiConnectionInfo\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\r\n\x05\x62ssid\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0f\n\x07ip_addr\x18\x04 \x01(\tB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "wifi_connection_info_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_WIFICONNECTIONINFO"]._serialized_start = 49
    _globals["_WIFICONNECTIONINFO"]._serialized_end = 133
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: multi_photography_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fmulti_photography_options.proto\x12\x11insta360.messages\x1a\x0bvideo.proto"\x9e\x05\n\x17MultiPhotographyOptions\x12<\n\x10recordResolution\x18\x01 \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x1f\n\x17\x65nableInternalFlowstate\x18\x02 \x01(\x08\x12P\n\x0e\x64imentsionType\x18\x03 \x01(\x0e\x32\x38.insta360.messages.MultiPhotographyOptions.DimensionType\x12I\n\nvisionType\x18\x04 \x01(\x0e\x32\x35.insta360.messages.MultiPhotographyOptions.VisionType"K\n\rDimensionType\x12\x1d\n\x19\x44IMENSION_TYPE_HORIZONTAL\x10\x00\x12\x1b\n\x17\x44IMENSION_TYPE_VERTICAL\x10\x01"\xb9\x02\n\nVisionType\x12\x14\n\x10VISION_TYPE_WIDE\x10\x00\x12\x16\n\x12VISION_TYPE_LINEAR\x10\x01\x12\x19\n\x15VISION_TYPE_ULTRAWIDE\x10\x02\x12\x16\n\x12VISION_TYPE_NARROW\x10\x03\x12\x13\n\x0fVISION_TYPE_POV\x10\x04\x12\x1b\n\x17VISION_TYPE_LINEAR_PLUS\x10\x05\x12\x1e\n\x1aVISION_TYPE_LINEAR_HORIZON\x10\x06\x12\x18\n\x14VISION_TYPE_TYPE_FPV\x10\x07\x12\x1a\n\x16VISION_TYPE_TYPE_SUPER\x10\x08\x12\x1f\n\x1bVISION_TYPE_TYPE_TINYPLANET\x10\t\x12!\n\x1dVISION_TYPE_TYPE_INFINITYWIDE\x10\n*\xc4\x01\n\x1bMultiPhotographyOptionsType\x12$\n MULTI_PHOTOGRAPHY_OPTION_UNKNOWN\x10\x00\x12\x0e\n\nRESOLUTION\x10\x01\x12"\n\x1ePHOTOGRAPHY_INTERNAL_FLOWSTATE\x10\x02\x12\x12\n\x0e\x44IMENSION_TYPE\x10\x03\x12\x0f\n\x0bVISION_TYPE\x10\x04\x12&\n"MULTI_PHOTOGRAPHY_OPTIONS_TYPE_NUM\x10\x05\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "multi_photography_options_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_MULTIPHOTOGRAPHYOPTIONSTYPE"]._serialized_start = 741
    _globals["_MULTIPHOTOGRAPHYOPTIONSTYPE"]._serialized_end = 937
    _globals["_MULTIPHOTOGRAPHYOPTIONS"]._serialized_start = 68
    _globals["_MULTIPHOTOGRAPHYOPTIONS"]._serialized_end = 738
    _globals["_MULTIPHOTOGRAPHYOPTIONS_DIMENSIONTYPE"]._serialized_start = 347
    _globals["_MULTIPHOTOGRAPHYOPTIONS_DIMENSIONTYPE"]._serialized_end = 422
    _globals["_MULTIPHOTOGRAPHYOPTIONS_VISIONTYPE"]._serialized_start = 425
    _globals["_MULTIPHOTOGRAPHYOPTIONS_VISIONTYPE"]._serialized_end = 738
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: support_take_photo_on_rec.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fsupport_take_photo_on_rec.proto\x12\x11insta360.messages"\xaa\x01\n!NotificationSupportTakePhotoInREC\x12U\n\x06status\x18\x01 \x01(\x0e\x32\x45.insta360.messages.NotificationSupportTakePhotoInREC.SupportTakephoto".\n\x10SupportTakephoto\x12\r\n\tNosupport\x10\x00\x12\x0b\n\x07Support\x10\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "support_take_photo_on_rec_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONSUPPORTTAKEPHOTOINREC"]._serialized_start = 55
    _globals["_NOTIFICATIONSUPPORTTAKEPHOTOINREC"]._serialized_end = 225
    _globals[
        "_NOTIFICATIONSUPPORTTAKEPHOTOINREC_SUPPORTTAKEPHOTO"
    ]._serialized_start = 179
    _globals[
        "_NOTIFICATIONSUPPORTTAKEPHOTOINREC_SUPPORTTAKEPHOTO"
    ]._serialized_end = 225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_file.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from file_type_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0eget_file.proto\x12\x11insta360.messages\x1a\x0f\x66ile_type.proto"9\n\x07GetFile\x12.\n\tfile_type\x18\x01 \x01(\x0e\x32\x1b.insta360.messages.FileType"+\n\x0bGetFileResp\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "get_file_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETFILE"]._serialized_start = 54
    _globals["_GETFILE"]._serialized_end = 111
    _globals["_GETFILERESP"]._serialized_start = 113
    _globals["_GETFILERESP"]._serialized_end = 156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_current_capture_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capture_state_pb2 import *
from capture_trigger_source_pb2 import *
from interval_rec_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n get_current_capture_status.proto\x12\x11insta360.messages\x1a\x13\x63\x61pture_state.proto\x1a\x1c\x63\x61pture_trigger_source.proto\x1a\x17interval_rec_info.proto"\xce\x03\n\x13\x43\x61meraCaptureStatus\x12\x34\n\x05state\x18\x01 \x01(\x0e\x32%.insta360.messages.CameraCaptureState\x12\x14\n\x0c\x63\x61pture_time\x18\x02 \x01(\r\x12\x14\n\x0c\x63\x61pture_nums\x18\x03 \x01(\r\x12\x1a\n\x12keyTimePointDetail\x18\x04 \x01(\t\x12\x45\n\x0etrigger_source\x18\x05 \x01(\x0e\x32-.insta360.messages.CameraCaptureTriggerSource\x12\x15\n\rinterval_time\x18\x06 \x01(\r\x12\x15\n\rexposure_mode\x18\x07 \x01(\r\x12\x17\n\x0fmax_record_time\x18\x08 \x01(\x05\x12\x18\n\x10max_pre_rec_time\x18\t \x01(\r\x12\x41\n\x0f\x63\x61pture_submode\x18\n \x01(\x0e\x32(.insta360.messages.CameraCaptureSubState\x12<\n\x10interval_recInfo\x18\x0b \x01(\x0b\x32".insta360.messages.IntervalRecInfo\x12\x10\n\x08\x64uration\x18\x0c \x01(\r"U\n\x1bGetCurrentCaptureStatusResp\x12\x36\n\x06status\x18\x01 \x01(\x0b\x32&.insta360.messages.CameraCaptureStatusB\x08\xa2\x02\x05INSPBP\x00P\x01P\x02\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_current_capture_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERACAPTURESTATUS"]._serialized_start = 132
    _globals["_CAMERACAPTURESTATUS"]._serialized_end = 594
    _globals["_GETCURRENTCAPTURESTATUSRESP"]._serialized_start = 596
    _globals["_GETCURRENTCAPTURESTATUSRESP"]._serialized_end = 681
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: start_capture.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13start_capture.proto\x12\x11insta360.messages\x1a\roptions.proto"<\n\x0cStartCapture\x12,\n\x04mode\x18\x01 \x01(\x0e\x32\x1e.insta360.messages.CaptureMode"\x12\n\x10StartCaptureRespB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "start_capture_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_STARTCAPTURE"]._serialized_start = 57
    _globals["_STARTCAPTURE"]._serialized_end = 117
    _globals["_STARTCAPTURERESP"]._serialized_start = 119
    _globals["_STARTCAPTURERESP"]._serialized_end = 137
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_file_list.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from media_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13get_file_list.proto\x12\x11insta360.messages\x1a\x0bmedia.proto"]\n\x0bGetFileList\x12\x30\n\nmedia_type\x18\x01 \x01(\x0e\x32\x1c.insta360.messages.MediaType\x12\r\n\x05start\x18\x02 \x01(\r\x12\r\n\x05limit\x18\x03 \x01(\r"3\n\x0fGetFileListResp\x12\x0b\n\x03uri\x18\x01 \x03(\t\x12\x13\n\x0btotal_count\x18\x02 \x01(\rB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "get_file_list_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETFILELIST"]._serialized_start = 55
    _globals["_GETFILELIST"]._serialized_end = 148
    _globals["_GETFILELISTRESP"]._serialized_start = 150
    _globals["_GETFILELISTRESP"]._serialized_end = 201
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_wifi_connection_result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from wifi_connection_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#camera_wifi_connection_result.proto\x12\x11insta360.messages\x1a\x1awifi_connection_info.proto"\x91\x02\n\x1a\x43\x61meraWifiConnectionResult\x12\x62\n\x16wifi_connection_result\x18\x01 \x01(\x0e\x32\x42.insta360.messages.CameraWifiConnectionResult.WifiConnectionResult\x12\x43\n\x14wifi_connection_info\x18\x02 \x01(\x0b\x32%.insta360.messages.WifiConnectionInfo"J\n\x14WifiConnectionResult\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07TIMEOUT\x10\x01\x12\x18\n\x14\x45RROR_CONNECT_FAILED\x10\x02\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "camera_wifi_connection_result_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CAMERAWIFICONNECTIONRESULT"]._serialized_start = 87
    _globals["_CAMERAWIFICONNECTIONRESULT"]._serialized_end = 360
    _globals["_CAMERAWIFICONNECTIONRESULT_WIFICONNECTIONRESULT"]._serialized_start = 286
    _globals["_CAMERAWIFICONNECTIONRESULT_WIFICONNECTIONRESULT"]._serialized_end = 360
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: take_picture.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from photo_pb2 import *
from media_pb2 import *
from sensor_pb2 import *
from extra_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12take_picture.proto\x12\x11insta360.messages\x1a\x0bphoto.proto\x1a\x0bmedia.proto\x1a\x0csensor.proto\x1a\x10\x65xtra_info.proto"\xe8\x02\n\x0bTakePicture\x12\x31\n\x04mode\x18\x01 \x01(\x0e\x32#.insta360.messages.TakePicture.Mode\x12\x38\n\x0e\x65xtra_metadata\x18\x02 \x01(\x0b\x32 .insta360.messages.ExtraMetadata\x12\x13\n\x0b\x61\x65\x62_ev_bias\x18\x03 \x03(\x11\x12;\n\x10raw_capture_type\x18\x04 \x01(\x0e\x32!.insta360.messages.RawCaptureType\x12\x1a\n\x12isInstaPanoEnabled\x18\x05 \x01(\x08\x12\x34\n\x0b\x66ocusSensor\x18\x06 \x01(\x0e\x32\x1f.insta360.messages.SensorDevice\x12\x11\n\tselfTimer\x18\x07 \x01(\r"5\n\x04Mode\x12\n\n\x06NORMAL\x10\x00\x12\x07\n\x03\x41\x45\x42\x10\x01\x12\t\n\x05\x42URST\x10\x03\x12\r\n\tAEB_NIGHT\x10\x04"\x9c\x01\n\x13TakePictureResponse\x12\'\n\x05image\x18\x01 \x01(\x0b\x32\x18.insta360.messages.Photo\x12,\n\naeb_images\x18\x02 \x03(\x0b\x32\x18.insta360.messages.Photo\x12.\n\x0c\x62urst_images\x18\x03 \x03(\x0b\x32\x18.insta360.messages.PhotoB\x08\xa2\x02\x05INSPBP\x00P\x01P\x02P\x03\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "take_picture_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_TAKEPICTURE"]._serialized_start = 100
    _globals["_TAKEPICTURE"]._serialized_end = 460
    _globals["_TAKEPICTURE_MODE"]._serialized_start = 407
    _globals["_TAKEPICTURE_MODE"]._serialized_end = 460
    _globals["_TAKEPICTURERESPONSE"]._serialized_start = 463
    _globals["_TAKEPICTURERESPONSE"]._serialized_end = 619
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: take_picture_state_update.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ftake_picture_state_update.proto\x12\x11insta360.messages"\xba\x01\n"NotificationTakePictureStateUpdate\x12U\n\x05state\x18\x01 \x01(\x0e\x32\x46.insta360.messages.NotificationTakePictureStateUpdate.TakePictureState"=\n\x10TakePictureState\x12\x0b\n\x07SHUTTER\x10\x00\x12\x0c\n\x08\x43OMPRESS\x10\x01\x12\x0e\n\nWRITE_FILE\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "take_picture_state_update_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONTAKEPICTURESTATEUPDATE"]._serialized_start = 55
    _globals["_NOTIFICATIONTAKEPICTURESTATEUPDATE"]._serialized_end = 241
    _globals[
        "_NOTIFICATIONTAKEPICTURESTATEUPDATE_TAKEPICTURESTATE"
    ]._serialized_start = 180
    _globals[
        "_NOTIFICATIONTAKEPICTURESTATEUPDATE_TAKEPICTURESTATE"
    ]._serialized_end = 241
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: key_pressed.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11key_pressed.proto\x12\x11insta360.messages"\xa0\x01\n\x16NotificatoinKeyPressed\x12?\n\x06key_id\x18\x01 \x01(\x0e\x32/.insta360.messages.NotificatoinKeyPressed.KeyId"E\n\x05KeyId\x12\x12\n\x0e\x46\x30_SHORT_PRESS\x10\x00\x12\x13\n\x0f\x46\x30_DOUBLE_PRESS\x10\x01\x12\x13\n\x0f\x46\x30_TRIPLE_PRESS\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "key_pressed_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATOINKEYPRESSED"]._serialized_start = 41
    _globals["_NOTIFICATOINKEYPRESSED"]._serialized_end = 201
    _globals["_NOTIFICATOINKEYPRESSED_KEYID"]._serialized_start = 132
    _globals["_NOTIFICATOINKEYPRESSED_KEYID"]._serialized_end = 201
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: check_authorization.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19\x63heck_authorization.proto\x12\x11insta360.messages" \n\x12\x43heckAuthorization\x12\n\n\x02id\x18\x01 \x01(\t"\xbe\x01\n\x16\x43heckAuthorizationResp\x12[\n\x14\x61uthorization_status\x18\x01 \x01(\x0e\x32=.insta360.messages.CheckAuthorizationResp.AuthorizationStatus"G\n\x13\x41uthorizationStatus\x12\x0e\n\nAUTHORIZED\x10\x00\x12\x10\n\x0cUNAUTHORIZED\x10\x01\x12\x0e\n\nSYSTEMBUSY\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "check_authorization_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CHECKAUTHORIZATION"]._serialized_start = 48
    _globals["_CHECKAUTHORIZATION"]._serialized_end = 80
    _globals["_CHECKAUTHORIZATIONRESP"]._serialized_start = 83
    _globals["_CHECKAUTHORIZATIONRESP"]._serialized_end = 273
    _globals["_CHECKAUTHORIZATIONRESP_AUTHORIZATIONSTATUS"]._serialized_start = 202
    _globals["_CHECKAUTHORIZATIONRESP_AUTHORIZATIONSTATUS"]._serialized_end = 273
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: usbcard_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14usbcard_status.proto\x12\x11insta360.messages"\xad\x01\n\rUsbCardStatus\x12.\n\x05state\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.UsbCardState\x12\x18\n\x10tf_card_capacity\x18\x02 \x01(\r\x12\x1d\n\x15tf_card_used_capacity\x18\x03 \x01(\r\x12\x1a\n\x12\x62\x61\x63kup_total_files\x18\x04 \x01(\r\x12\x17\n\x0f\x62\x61\x63ked_up_files\x18\x05 \x01(\r*\xc5\x02\n\x0cUsbCardState\x12\x15\n\x11USBCARD_CONNECTED\x10\x00\x12\x18\n\x14USBCARD_DISCONNECTED\x10\x01\x12\x1b\n\x17USBCARD_CONNECTED_PHONE\x10\x02\x12\x16\n\x12USBCARD_NO_TF_CARD\x10\x03\x12\x13\n\x0fUSBCARD_TF_FULL\x10\x04\x12\x12\n\x0eUSBCARD_TF_ERR\x10\x05\x12\x17\n\x13USBCARD_BACKUP_SUCC\x10\x06\x12\x16\n\x12USBCARD_BACKUP_ERR\x10\x07\x12\x15\n\x11USBCARD_OTHER_ERR\x10\x08\x12\x15\n\x11USBCARD_BACKUPING\x10\t\x12\x16\n\x12USBCARD_BACKUP_END\x10\n\x12\x17\n\x13USBCARD_FORMAT_SUCC\x10\x0b\x12\x16\n\x12USBCARD_FORMAT_ERR\x10\x0c\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "usbcard_status_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_USBCARDSTATE"]._serialized_start = 220
    _globals["_USBCARDSTATE"]._serialized_end = 545
    _globals["_USBCARDSTATUS"]._serialized_start = 44
    _globals["_USBCARDSTATUS"]._serialized_end = 217
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_cloud_storage_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cloud_storage_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eset_cloud_storage_status.proto\x12\x11insta360.messages\x1a\x13\x63loud_storage.proto"a\n\x1bSetCloudStorageUploadStatus\x12\x42\n\rupload_params\x18\x01 \x01(\x0b\x32+.insta360.messages.CloudStorageUploadParams"!\n\x1fSetCloudStorageUploadStatusResp"[\n\x19SetCloudStorageBindStatus\x12>\n\x0b\x62ind_params\x18\x01 \x01(\x0b\x32).insta360.messages.CloudStorageBindParams"\x9c\x01\n\x1dSetCloudStorageBindStatusResp\x12K\n\x06result\x18\x01 \x01(\x0e\x32;.insta360.messages.SetCloudStorageBindStatusResp.BindResult".\n\nBindResult\x12\x10\n\x0c\x42IND_SUCCESS\x10\x00\x12\x0e\n\nBIND_FAILD\x10\x01\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_cloud_storage_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETCLOUDSTORAGEUPLOADSTATUS"]._serialized_start = 74
    _globals["_SETCLOUDSTORAGEUPLOADSTATUS"]._serialized_end = 171
    _globals["_SETCLOUDSTORAGEUPLOADSTATUSRESP"]._serialized_start = 173
    _globals["_SETCLOUDSTORAGEUPLOADSTATUSRESP"]._serialized_end = 206
    _globals["_SETCLOUDSTORAGEBINDSTATUS"]._serialized_start = 208
    _globals["_SETCLOUDSTORAGEBINDSTATUS"]._serialized_end = 299
    _globals["_SETCLOUDSTORAGEBINDSTATUSRESP"]._serialized_start = 302
    _globals["_SETCLOUDSTORAGEBINDSTATUSRESP"]._serialized_end = 458
    _globals["_SETCLOUDSTORAGEBINDSTATUSRESP_BINDRESULT"]._serialized_start = 412
    _globals["_SETCLOUDSTORAGEBINDSTATUSRESP_BINDRESULT"]._serialized_end = 458
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_wifi_seize.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14set_wifi_seize.proto\x12\x11insta360.messages"\x99\x01\n\x12SetWifiSeizeEnable\x12\x44\n\x05state\x18\x01 \x01(\x0e\x32\x35.insta360.messages.SetWifiSeizeEnable.ConnectionState"=\n\x0f\x43onnectionState\x12\x0b\n\x07unknown\x10\x00\x12\x0f\n\x0bmonopolized\x10\x01\x12\x0c\n\x08seizable\x10\x02"\x18\n\x16SetWifiSeizeEnableRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_wifi_seize_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETWIFISEIZEENABLE"]._serialized_start = 44
    _globals["_SETWIFISEIZEENABLE"]._serialized_end = 197
    _globals["_SETWIFISEIZEENABLE_CONNECTIONSTATE"]._serialized_start = 136
    _globals["_SETWIFISEIZEENABLE_CONNECTIONSTATE"]._serialized_end = 197
    _globals["_SETWIFISEIZEENABLERESP"]._serialized_start = 199
    _globals["_SETWIFISEIZEENABLERESP"]._serialized_end = 223
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_access_camera_file_state.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"set_access_camera_file_state.proto\x12\x11insta360.messages"\xbf\x01\n\x18SetAccessCameraFileState\x12\x46\n\x05state\x18\x01 \x01(\x0e\x32\x37.insta360.messages.SetAccessCameraFileState.AccessState"[\n\x0b\x41\x63\x63\x65ssState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04IDLE\x10\x01\x12\n\n\x06\x45XPORT\x10\x02\x12\x0c\n\x08\x44OWNLOAD\x10\x03\x12\x0c\n\x08PLAYBACK\x10\x04\x12\r\n\tLIVE_VIEW\x10\x05"\x1e\n\x1cSetAccessCameraFileStateRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_access_camera_file_state_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETACCESSCAMERAFILESTATE"]._serialized_start = 58
    _globals["_SETACCESSCAMERAFILESTATE"]._serialized_end = 249
    _globals["_SETACCESSCAMERAFILESTATE_ACCESSSTATE"]._serialized_start = 158
    _globals["_SETACCESSCAMERAFILESTATE_ACCESSSTATE"]._serialized_end = 249
    _globals["_SETACCESSCAMERAFILESTATERESP"]._serialized_start = 251
    _globals["_SETACCESSCAMERAFILESTATERESP"]._serialized_end = 281
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_timelapse_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from timelapse_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bget_timelapse_options.proto\x12\x11insta360.messages\x1a\x0ftimelapse.proto"E\n\x13GetTimelapseOptions\x12.\n\x04mode\x18\x01 \x01(\x0e\x32 .insta360.messages.TimelapseMode"Y\n\x17GetTimelapseOptionsResp\x12>\n\x11timelapse_options\x18\x01 \x01(\x0b\x32#.insta360.messages.TimelapseOptionsB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_timelapse_options_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETTIMELAPSEOPTIONS"]._serialized_start = 67
    _globals["_GETTIMELAPSEOPTIONS"]._serialized_end = 136
    _globals["_GETTIMELAPSEOPTIONSRESP"]._serialized_start = 138
    _globals["_GETTIMELAPSEOPTIONSRESP"]._serialized_end = 227
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_cloud_storage_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cloud_storage_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eget_cloud_storage_status.proto\x12\x11insta360.messages\x1a\x13\x63loud_storage.proto"\x1d\n\x1bGetCloudStorageUploadStatus"e\n\x1fGetCloudStorageUploadStatusResp\x12\x42\n\rupload_params\x18\x01 \x01(\x0b\x32+.insta360.messages.CloudStorageUploadParams"\x1b\n\x19GetCloudStorageBindStatus"_\n\x1dGetCloudStorageBindStatusResp\x12>\n\x0b\x62ind_params\x18\x01 \x01(\x0b\x32).insta360.messages.CloudStorageBindParamsB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_cloud_storage_status_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETCLOUDSTORAGEUPLOADSTATUS"]._serialized_start = 74
    _globals["_GETCLOUDSTORAGEUPLOADSTATUS"]._serialized_end = 103
    _globals["_GETCLOUDSTORAGEUPLOADSTATUSRESP"]._serialized_start = 105
    _globals["_GETCLOUDSTORAGEUPLOADSTATUSRESP"]._serialized_end = 206
    _globals["_GETCLOUDSTORAGEBINDSTATUS"]._serialized_start = 208
    _globals["_GETCLOUDSTORAGEBINDSTATUS"]._serialized_end = 235
    _globals["_GETCLOUDSTORAGEBINDSTATUSRESP"]._serialized_start = 237
    _globals["_GETCLOUDSTORAGEBINDSTATUSRESP"]._serialized_end = 332
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exposure_update.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *
from exposure_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15\x65xposure_update.proto\x12\x11insta360.messages\x1a\roptions.proto\x1a\x0e\x65xposure.proto"\xcc\x01\n\x1aNotificationExposureUpdate\x12\x36\n\rfunction_mode\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.FunctionMode\x12:\n\x0estill_exposure\x18\x02 \x01(\x0b\x32".insta360.messages.ExposureOptions\x12:\n\x0evideo_exposure\x18\x03 \x01(\x0b\x32".insta360.messages.ExposureOptionsB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "exposure_update_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONEXPOSUREUPDATE"]._serialized_start = 76
    _globals["_NOTIFICATIONEXPOSUREUPDATE"]._serialized_end = 280
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: start_timeshift.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x15start_timeshift.proto\x12\x11insta360.messages"\x10\n\x0eStartTimeShift"\x14\n\x12StartTimeShiftRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "start_timeshift_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_STARTTIMESHIFT"]._serialized_start = 44
    _globals["_STARTTIMESHIFT"]._serialized_end = 60
    _globals["_STARTTIMESHIFTRESP"]._serialized_start = 62
    _globals["_STARTTIMESHIFTRESP"]._serialized_end = 82
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: detect_face.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11\x64\x65tect_face.proto\x12\x11insta360.messages"\xe9\x01\n\x16NotificationDetectFace\x12\x15\n\rdetectFaceNum\x18\x01 \x01(\r\x12\x46\n\x06reason\x18\x02 \x01(\x0e\x32\x36.insta360.messages.NotificationDetectFace.ChangeReason\x12\x1c\n\x14isRecommendPorFilter\x18\x03 \x01(\x08"R\n\x0c\x43hangeReason\x12\x0e\n\nFPS_CHANGE\x10\x00\x12\x18\n\x14\x45XPOSURE_MODE_CHANGE\x10\x01\x12\x18\n\x14RECOMMEND_POR_FILTER\x10\x02\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "detect_face_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONDETECTFACE"]._serialized_start = 41
    _globals["_NOTIFICATIONDETECTFACE"]._serialized_end = 274
    _globals["_NOTIFICATIONDETECTFACE_CHANGEREASON"]._serialized_start = 192
    _globals["_NOTIFICATIONDETECTFACE_CHANGEREASON"]._serialized_end = 274
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: active_sensor_device.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensor_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1a\x61\x63tive_sensor_device.proto\x12\x11insta360.messages\x1a\x0csensor.proto"\x17\n\x15GetActiveSensorDevice"b\n\x19GetActiveSensorDeviceResp\x12/\n\x06\x64\x65vice\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.SensorDevice\x12\x14\n\x0cmedia_offset\x18\x02 \x01(\t"H\n\x15SetActiveSensorDevice\x12/\n\x06\x64\x65vice\x18\x01 \x01(\x0e\x32\x1f.insta360.messages.SensorDevice"1\n\x19SetActiveSensorDeviceResp\x12\x14\n\x0cmedia_offset\x18\x01 \x01(\tB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "active_sensor_device_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETACTIVESENSORDEVICE"]._serialized_start = 63
    _globals["_GETACTIVESENSORDEVICE"]._serialized_end = 86
    _globals["_GETACTIVESENSORDEVICERESP"]._serialized_start = 88
    _globals["_GETACTIVESENSORDEVICERESP"]._serialized_end = 186
    _globals["_SETACTIVESENSORDEVICE"]._serialized_start = 188
    _globals["_SETACTIVESENSORDEVICE"]._serialized_end = 260
    _globals["_SETACTIVESENSORDEVICERESP"]._serialized_start = 262
    _globals["_SETACTIVESENSORDEVICERESP"]._serialized_end = 311
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: darkeis_status.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x64\x61rkeis_status.proto\x12\x11insta360.messages"\x80\x02\n\x19NotificationDarkEisStatus\x12R\n\x0e\x64\x61rkeis_status\x18\x01 \x01(\x0e\x32:.insta360.messages.NotificationDarkEisStatus.DarkEisStatus"\x8e\x01\n\rDarkEisStatus\x12\x17\n\x13\x44\x41RKEIS_ENABLE_SHOW\x10\x00\x12\x17\n\x13\x44\x41RKEIS_ENABLE_HIDE\x10\x01\x12\x18\n\x14\x44\x41RKEIS_DISABLE_SHOW\x10\x02\x12\x18\n\x14\x44\x41RKEIS_DISABLE_HIDE\x10\x03\x12\x17\n\x13\x44\x41RKEIS_DARKEIS_NUM\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "darkeis_status_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONDARKEISSTATUS"]._serialized_start = 44
    _globals["_NOTIFICATIONDARKEISSTATUS"]._serialized_end = 300
    _globals["_NOTIFICATIONDARKEISSTATUS_DARKEISSTATUS"]._serialized_start = 158
    _globals["_NOTIFICATIONDARKEISSTATUS_DARKEISSTATUS"]._serialized_end = 300
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_standby_mode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16set_standby_mode.proto\x12\x11insta360.messages"\xb5\x01\n\x0eSetStandbyMode\x12\x43\n\x0cstandby_mode\x18\x01 \x01(\x0e\x32-.insta360.messages.SetStandbyMode.StandbyMode"^\n\x0bStandbyMode\x12\x18\n\x14STANDBY_MODE_UNKNOWN\x10\x00\x12\x1b\n\x17STANDBY_MODE_LOW_ENERGY\x10\x01\x12\x18\n\x14STANDBY_MODE_WAKE_UP\x10\x02"\x14\n\x12SetStandbyModeRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_standby_mode_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETSTANDBYMODE"]._serialized_start = 46
    _globals["_SETSTANDBYMODE"]._serialized_end = 227
    _globals["_SETSTANDBYMODE_STANDBYMODE"]._serialized_start = 133
    _globals["_SETSTANDBYMODE_STANDBYMODE"]._serialized_end = 227
    _globals["_SETSTANDBYMODERESP"]._serialized_start = 229
    _globals["_SETSTANDBYMODERESP"]._serialized_end = 249
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_wifi_connect_list.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from wifi_connection_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bset_wifi_connect_list.proto\x12\x11insta360.messages\x1a\x1awifi_connection_info.proto"4\n\x12SetWifiConnectList\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t"\xa0\x01\n\x16SetWifiConnectListResp\x12=\n\x03res\x18\x01 \x01(\x0e\x32\x30.insta360.messages.SetWifiConnectListResp.Result"G\n\x06Result\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0eSSID_NOT_FOUND\x10\x02\x12\x12\n\x0ePASSWORD_ERROR\x10\x03"%\n\x15\x44\x65leteWifiConnectList\x12\x0c\n\x04ssid\x18\x01 \x01(\t"\x92\x01\n\x19\x44\x65leteWifiConnectListResp\x12@\n\x03res\x18\x01 \x01(\x0e\x32\x33.insta360.messages.DeleteWifiConnectListResp.Result"3\n\x06Result\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0eSSID_NOT_FOUND\x10\x02\x42\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "set_wifi_connect_list_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETWIFICONNECTLIST"]._serialized_start = 78
    _globals["_SETWIFICONNECTLIST"]._serialized_end = 130
    _globals["_SETWIFICONNECTLISTRESP"]._serialized_start = 133
    _globals["_SETWIFICONNECTLISTRESP"]._serialized_end = 293
    _globals["_SETWIFICONNECTLISTRESP_RESULT"]._serialized_start = 222
    _globals["_SETWIFICONNECTLISTRESP_RESULT"]._serialized_end = 293
    _globals["_DELETEWIFICONNECTLIST"]._serialized_start = 295
    _globals["_DELETEWIFICONNECTLIST"]._serialized_end = 332
    _globals["_DELETEWIFICONNECTLISTRESP"]._serialized_start = 335
    _globals["_DELETEWIFICONNECTLISTRESP"]._serialized_end = 481
    _globals["_DELETEWIFICONNECTLISTRESP_RESULT"]._serialized_start = 222
    _globals["_DELETEWIFICONNECTLISTRESP_RESULT"]._serialized_end = 273
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: offset_state.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x12offset_state.proto\x12\x11insta360.messages*\x80\x01\n\x0bOffsetState\x12\n\n\x06\x43ommon\x10\x00\x12\x11\n\rSphereProtect\x10\x01\x12\x0f\n\x0b\x44ivingWater\x10\x02\x12\x11\n\rDivingWater23\x10\x03\x12\r\n\tProtect_A\x10\x04\x12\r\n\tProtect_S\x10\x05\x12\x10\n\x0cProtect_Auto\x10\x06*S\n\x12OffsetDetectedType\x12\n\n\x06Unkown\x10\x00\x12\n\n\x06\x41uto_A\x10\x01\x12\n\n\x06\x41uto_S\x10\x02\x12\x0c\n\x08\x41uto_off\x10\x03\x12\x0b\n\x07\x41uto_AS\x10\x04\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "offset_state_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_OFFSETSTATE"]._serialized_start = 42
    _globals["_OFFSETSTATE"]._serialized_end = 170
    _globals["_OFFSETDETECTEDTYPE"]._serialized_start = 172
    _globals["_OFFSETDETECTEDTYPE"]._serialized_end = 255
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: start_live_stream.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *
from media_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17start_live_stream.proto\x12\x11insta360.messages\x1a\x0bvideo.proto\x1a\x0bmedia.proto"\x90\x03\n\x0fStartLiveStream\x12\x13\n\x0b\x65nableAudio\x18\x01 \x01(\x08\x12\x13\n\x0b\x65nableVideo\x18\x02 \x01(\x08\x12/\n\taudioType\x18\x03 \x01(\x0e\x32\x1c.insta360.messages.AACBSType\x12\x17\n\x0f\x61udioSampleRate\x18\x04 \x01(\r\x12\x14\n\x0c\x61udioBitrate\x18\x05 \x01(\r\x12\x14\n\x0cvideoBitrate\x18\x06 \x01(\r\x12\x36\n\nresolution\x18\x07 \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x12\n\nenableGyro\x18\x08 \x01(\x08\x12\x15\n\rvideoBitrate1\x18\t \x01(\r\x12\x37\n\x0bresolution1\x18\n \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x18\n\x10previewStreamNum\x18\x0b \x01(\r\x12\x14\n\x0c\x65nableRotate\x18\x0c \x01(\x08\x12\x11\n\tisForLive\x18\r \x01(\x08"\x15\n\x13StartLiveStreamRespB\x08\xa2\x02\x05INSPBP\x00P\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "start_live_stream_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_STARTLIVESTREAM"]._serialized_start = 73
    _globals["_STARTLIVESTREAM"]._serialized_end = 473
    _globals["_STARTLIVESTREAMRESP"]._serialized_start = 475
    _globals["_STARTLIVESTREAMRESP"]._serialized_end = 496
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sync_capture_mode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x17sync_capture_mode.proto\x12\x11insta360.messages*\xc8\x02\n\x0fSyncCaptureMode\x12\x15\n\x11SYNC_MODE_UNKNOWN\x10\x00\x12\x1a\n\x16SYNC_MODE_NORMAL_IMAGE\x10\x01\x12\x1a\n\x16SYNC_MODE_NORMAL_VIDEO\x10\x02\x12\x17\n\x13SYNC_MODE_HDR_IMAGE\x10\x03\x12\x17\n\x13SYNC_MODE_HDR_VIDEO\x10\x04\x12\x1c\n\x18SYNC_MODE_INTERVAL_IMAGE\x10\x05\x12\x1d\n\x19SYNC_MODE_TIMELAPSE_VIDEO\x10\x06\x12\x19\n\x15SYNC_MODE_BURST_PHOTO\x10\x07\x12\x1e\n\x1aSYNC_MODE_BULLETTIME_VIDEO\x10\x08\x12\x1d\n\x19SYNC_MODE_TIMESHIFT_VIDEO\x10\t\x12\x1d\n\x19SYNC_MODE_AEB_NIGHT_PHOTO\x10\nB\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "sync_capture_mode_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SYNCCAPTUREMODE"]._serialized_start = 47
    _globals["_SYNCCAPTUREMODE"]._serialized_end = 375
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exposure.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0e\x65xposure.proto\x12\x11insta360.messages"\xd8\x01\n\x0f\x45xposureOptions\x12;\n\x07program\x18\x01 \x01(\x0e\x32*.insta360.messages.ExposureOptions.Program\x12\x0b\n\x03iso\x18\x02 \x01(\r\x12\x15\n\rshutter_speed\x18\x03 \x01(\x01"d\n\x07Program\x12\x08\n\x04\x41UTO\x10\x00\x12\x10\n\x0cISO_PRIORITY\x10\x01\x12\x14\n\x10SHUTTER_PRIORITY\x10\x02\x12\n\n\x06MANUAL\x10\x03\x12\x0c\n\x08\x41\x44\x41PTIVE\x10\x04\x12\r\n\tFULL_AUTO\x10\x05\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "exposure_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_EXPOSUREOPTIONS"]._serialized_start = 38
    _globals["_EXPOSUREOPTIONS"]._serialized_end = 254
    _globals["_EXPOSUREOPTIONS_PROGRAM"]._serialized_start = 154
    _globals["_EXPOSUREOPTIONS_PROGRAM"]._serialized_end = 254
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from options_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11set_options.proto\x12\x11insta360.messages\x1a\roptions.proto"l\n\nSetOptions\x12\x33\n\x0coption_types\x18\x01 \x03(\x0e\x32\x1d.insta360.messages.OptionType\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.insta360.messages.Options"E\n\x0eSetOptionsResp\x12\x33\n\x0coption_types\x18\x01 \x03(\x0e\x32\x1d.insta360.messages.OptionTypeB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_options_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETOPTIONS"]._serialized_start = 55
    _globals["_SETOPTIONS"]._serialized_end = 163
    _globals["_SETOPTIONSRESP"]._serialized_start = 165
    _globals["_SETOPTIONSRESP"]._serialized_end = 234
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: message_code.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12message_code.proto\x12\x11insta360.messages*\xc2@\n\x0bMessageCode\x12\x17\n\x13PHONE_COMMAND_BEGIN\x10\x00\x12#\n\x1fPHONE_COMMAND_START_LIVE_STREAM\x10\x01\x12"\n\x1ePHONE_COMMAND_STOP_LIVE_STREAM\x10\x02\x12\x1e\n\x1aPHONE_COMMAND_TAKE_PICTURE\x10\x03\x12\x1f\n\x1bPHONE_COMMAND_START_CAPTURE\x10\x04\x12\x1e\n\x1aPHONE_COMMAND_STOP_CAPTURE\x10\x05\x12 \n\x1cPHONE_COMMAND_CANCEL_CAPTURE\x10\x06\x12\x1d\n\x19PHONE_COMMAND_SET_OPTIONS\x10\x07\x12\x1d\n\x19PHONE_COMMAND_GET_OPTIONS\x10\x08\x12)\n%PHONE_COMMAND_SET_PHOTOGRAPHY_OPTIONS\x10\t\x12)\n%PHONE_COMMAND_GET_PHOTOGRAPHY_OPTIONS\x10\n\x12 \n\x1cPHONE_COMMAND_GET_FILE_EXTRA\x10\x0b\x12\x1e\n\x1aPHONE_COMMAND_DELETE_FILES\x10\x0c\x12$\n\x1fPHONE_COMMAND_GET_EDITINFO_LIST\x10\xc9\x01\x12\x1f\n\x1bPHONE_COMMAND_GET_FILE_LIST\x10\r\x12.\n*PHONE_COMMAND_TAKE_PICTURE_WITHOUT_STORING\x10\x0e\x12,\n(PHONE_COMMAND_GET_CURRENT_CAPTURE_STATUS\x10\x0f\x12 \n\x1cPHONE_COMMAND_SET_FILE_EXTRA\x10\x10\x12\'\n#PHONE_COMMAND_GET_TIMELAPSE_OPTIONS\x10\x11\x12\'\n#PHONE_COMMAND_SET_TIMELAPSE_OPTIONS\x10\x12\x12\x1a\n\x16PHONE_COMMAND_GET_GYRO\x10\x13\x12!\n\x1dPHONE_COMMAND_START_TIMELAPSE\x10\x16\x12 \n\x1cPHONE_COMMAND_STOP_TIMELAPSE\x10\x17\x12\x1f\n\x1bPHONE_COMMAND_ERASE_SD_CARD\x10\x18\x12 \n\x1cPHONE_COMMAND_CALIBRATE_GYRO\x10\x19\x12$\n PHONE_COMMAND_SCAN_BT_PERIPHERAL\x10\x1a\x12*\n&PHONE_COMMAND_CONNECT_TO_BT_PERIPHERAL\x10\x1b\x12*\n&PHONE_COMMAND_DISCONNECT_BT_PERIPHERAL\x10\x1c\x12.\n*PHONE_COMMAND_GET_CONNECTED_BT_PERIPHERALS\x10\x1d\x12$\n PHONE_COMMAND_GET_MINI_THUMBNAIL\x10\x1e\x12$\n PHONE_COMMAND_TEST_SD_CARD_SPEED\x10\x1f\x12\x1f\n\x1bPHONE_COMMAND_REBOOT_CAMERA\x10 \x12"\n\x1ePHONE_COMMAND_OPEN_CAMERA_WIFI\x10!\x12#\n\x1fPHONE_COMMAND_CLOSE_CAMERA_WIFI\x10"\x12\x1c\n\x18PHONE_COMMAND_OPEN_IPERF\x10#\x12\x1d\n\x19PHONE_COMMAND_CLOSE_IPERF\x10$\x12#\n\x1fPHONE_COMMAND_GET_IPERF_AVERAGE\x10%\x12#\n\x1fPHONE_COMMAND_GET_FILEINFO_LIST\x10&\x12%\n!PHONE_COMMAND_CHECK_AUTHORIZATION\x10\'\x12&\n"PHONE_COMMAND_CANCEL_AUTHORIZATION\x10(\x12*\n&PHONE_COMMAND_START_BULLETTIME_CAPTURE\x10)\x12%\n!PHONE_COMMAND_SET_SUBMODE_OPTIONS\x10*\x12%\n!PHONE_COMMAND_GET_SUBMODE_OPTIONS\x10+\x12)\n%PHONE_COMMAND_STOP_BULLETTIME_CAPTURE\x10\x30\x12\x1b\n\x17PHONE_COMMAND_OPEN_OLED\x10\x31\x12\x1c\n\x18PHONE_COMMAND_CLOSE_OLED\x10\x32\x12#\n\x1fPHONE_COMMAND_START_HDR_CAPTURE\x10\x33\x12"\n\x1ePHONE_COMMAND_STOP_HDR_CAPTURE\x10\x34\x12\x1c\n\x18PHONE_COMMAND_UPLOAD_GPS\x10\x35\x12\'\n#PHONE_COMMAND_SET_SYNC_CAPTURE_MODE\x10\x36\x12\'\n#PHONE_COMMAND_GET_SYNC_CAPTURE_MODE\x10\x37\x12"\n\x1ePHONE_COMMAND_SET_STANDBY_MODE\x10\x38\x12*\n&PHONE_COMMAND_RESTORE_FACTORY_SETTINGS\x10\x39\x12.\n*PHONE_COMMAND_SET_TEMPORARY_OPTIONS_SWITCH\x10:\x12.\n*PHONE_COMMAND_GET_TEMPORARY_OPTIONS_SWITCH\x10;\x12$\n PHONE_COMMAND_SET_KEY_TIME_POINT\x10<\x12)\n%PHONE_COMMAND_START_TIMESHIFT_CAPTURE\x10=\x12(\n$PHONE_COMMAND_STOP_TIMESHIFT_CAPTURE\x10>\x12&\n"PHONE_COMMAND_SET_FLOWSTATE_ENABLE\x10?\x12&\n"PHONE_COMMAND_GET_FLOWSTATE_ENABLE\x10@\x12#\n\x1fPHONE_COMMAND_SET_ACTIVE_SENSOR\x10\x41\x12#\n\x1fPHONE_COMMAND_GET_ACTIVE_SENSOR\x10\x42\x12$\n PHONE_COMMAND_GET_RECORDING_FILE\x10G\x12/\n+PHONE_COMMAND_SET_MULTI_PHOTOGRAPHY_OPTIONS\x10\x43\x12/\n+PHONE_COMMAND_GET_MULTI_PHOTOGRAPHY_OPTIONS\x10\x44\x12*\n&PHONE_COMMAND_PREPARE_GET_FILE_PACKAGE\x10S\x12)\n%PHONE_COMMAND_GET_FILE_PACKAGE_FINISH\x10T\x12\'\n#PHONE_COMMAND_SET_WIFI_SEIZE_ENABLE\x10U\x12\'\n#PHONE_COMMAND_REQUEST_AUTHORIZATION\x10V\x12.\n*PHONE_COMMAND_CANCEL_REQUEST_AUTHORIZATION\x10W\x12(\n$PHONE_COMMAND_SET_BUTTON_PRESS_PARAM\x10g\x12(\n$PHONE_COMMAND_GET_BUTTON_PRESS_PARAM\x10h\x12 \n\x1cPHONE_COMMAND_IFRAME_REQUEST\x10i\x12*\n&PHONE_COMMAND_SET_WIFI_CONNECTION_INFO\x10p\x12*\n&PHONE_COMMAND_GET_WIFI_CONNECTION_INFO\x10q\x12.\n*PHONE_COMMAND_SET_ACCESS_CAMERA_FILE_STATE\x10v\x12\x1b\n\x17PHONE_COMMAND_SET_APPID\x10x\x12\x1c\n\x18PHONE_COMMAND_RESET_WIFI\x10}\x12\x30\n+PHONE_COMMAND_PREPARE_GET_FILE_SYNC_PACKAGE\x10\x97\x01\x12/\n*PHONE_COMMAND_GET_FILE_PACKAGE_SYNC_FINISH\x10\x98\x01\x12"\n\x1dPHONE_COMMAND_DARK_EIS_STATUS\x10\x9d\x01\x12"\n\x1dPHONE_COMMAND_PAUSE_RECORDING\x10\xa4\x01\x12#\n\x1ePHONE_COMMAND_NOTIFY_OTA_ERROR\x10\xa7\x01\x12 \n\x1bPHONE_COMMAND_DOWNLOAD_INFO\x10\xad\x01\x12)\n$PHONE_COMMAND_GET_DOWNLOAD_FILE_LIST\x10\xac\x01\x12\x30\n+PHONE_COMMAND_ADD_DOWNLOAD_LIST_RESULT_SYNC\x10\xbe\x01\x12+\n&CAMERA_NOTIFICATION_DELETE_FILE_RESULT\x10\xd7@\x12\'\n"PHONE_COMMAND_SET_CAMERA_LIVE_INFO\x10\x87\x01\x12\'\n"PHONE_COMMAND_GET_CAMERA_LIVE_INFO\x10\x88\x01\x12$\n\x1fPHONE_COMMAND_START_CAMERA_LIVE\x10\x89\x01\x12#\n\x1ePHONE_COMMAND_STOP_CAMERA_LIVE\x10\x90\x01\x12+\n&PHONE_COMMAND_START_CAMERA_LIVE_RECORD\x10\x91\x01\x12*\n%PHONE_COMMAND_STOP_CAMERA_LIVE_RECORD\x10\x92\x01\x12 \n\x1bPHONE_COMMAND_SET_WIFI_MODE\x10\x93\x01\x12%\n PHONE_COMMAND_GET_WIFI_SCAN_LIST\x10\x94\x01\x12*\n%PHONE_COMMAND_GET_CONNECTED_WIFI_LIST\x10\x95\x01\x12 \n\x1bPHONE_COMMAND_GET_WIFI_MODE\x10\x96\x01\x12\x18\n\x13PHONE_REQUEST_BEGIN\x10\x80 \x12\x1e\n\x19\x43\x41MERA_NOTIFICATION_BEGIN\x10\x80@\x12*\n%CAMERA_NOTIFICATION_INTERVAL_REC_INFO\x10\xce@\x12\x32\n-CAMERA_NOTIFICATION_FIRMWARE_UPGRADE_COMPLETE\x10\x81@\x12+\n&CAMERA_NOTIFICATION_CAPTURE_AUTO_SPLIT\x10\x82@\x12\'\n"CAMERA_NOTIFICATION_BATTERY_UPDATE\x10\x83@\x12$\n\x1f\x43\x41MERA_NOTIFICATION_BATTERY_LOW\x10\x84@\x12!\n\x1c\x43\x41MERA_NOTIFICATION_SHUTDOWN\x10\x85@\x12\'\n"CAMERA_NOTIFICATION_STORAGE_UPDATE\x10\x86@\x12%\n CAMERA_NOTIFICATION_STORAGE_FULL\x10\x87@\x12$\n\x1f\x43\x41MERA_NOTIFICATION_KEY_PRESSED\x10\x88@\x12(\n#CAMERA_NOTIFICATION_CAPTURE_STOPPED\x10\x89@\x12\x32\n-CAMERA_NOTIFICATION_TAKE_PICTURE_STATE_UPDATE\x10\x8a@\x12.\n)CAMERA_NOTIFICATION_DELETE_FILES_PROGRESS\x10\x8b@\x12%\n CAMERA_NOTIFICATION_PHONE_INSERT\x10\x8c@\x12/\n*CAMERA_NOTIFICATION_BT_DISCOVER_PERIPHERAL\x10\x8d@\x12\x33\n.CAMERA_NOTIFICATION_BT_CONNECTED_TO_PERIPHERAL\x10\x8e@\x12\x33\n.CAMERA_NOTIFICATION_BT_DISCONNECTED_PERIPHERAL\x10\x8f@\x12/\n*CAMERA_NOTIFICATION_CURRENT_CAPTURE_STATUS\x10\x90@\x12-\n(CAMERA_NOTIFICATION_AUTHORIZATION_RESULT\x10\x91@\x12\x30\n+CAMERA_NOTIFICATION_TIMELAPSE_STATUS_UPDATE\x10\x92@\x12\x31\n,CAMERA_NOTIFICATION_SYNC_CAPTURE_MODE_UPDATE\x10\x93@\x12\x34\n/CAMERA_NOTIFICATION_SYNC_CAPTURE_BUTTON_TRIGGER\x10\x94@\x12.\n)CAMERA_NOTIFICATION_BT_REMOTE_VER_UPDATED\x10\x95@\x12.\n)CAMERA_NOTIFICATION_CAM_TEMPERATURE_VALUE\x10\x96@\x12\'\n"CAMERA_NOTIFICATION_CAM_WIFI_START\x10\x97@\x12\x32\n-CAMERA_NOTIFICATION_CAM_BT_MSG_ANALYZE_FAILED\x10\x98@\x12\x32\n-CAMERA_NOTIFICATION_CHARGE_BOX_BATTERY_UPDATE\x10\x99@\x12.\n)CAMERA_NOTIFICATION_LIVEVIEW_BEGIN_ROTATE\x10\x9b@\x12(\n#CAMERA_NOTIFICATION_EXPOSURE_UPDATE\x10\x9c@\x12\x32\n-CAMERA_NOTIFICATION_CHARGE_BOX_CONNECT_STATUS\x10\x9e@\x12$\n\x1f\x43\x41MERA_NOTIFICATION_WIFI_STATUS\x10\xa8@\x12\x32\n-CAMERA_NOTIFICATION_UPDATE_LIVE_STREAM_PARAMS\x10\xaa@\x12\x36\n1CAMERA_NOTIFICATION_FIRMWARE_UPGRADE_STATUS_TOAPP\x10\xae@\x12+\n&CAMERA_NOTIFICATION_CAMERA_LIVE_STATUS\x10\xb6@\x12)\n$CAMERA_NOTIFICATION_WIFI_MODE_CHANGE\x10\xb7@\x12+\n&CAMERA_NOTIFICATION_DATA_EXPORT_STATUS\x10\xb8@\x12/\n*CAMERA_NOTIFICATION_WIFI_SCAN_LIST_CHANGED\x10\xb9@\x12&\n!CAMERA_NOTIFICATION_DETECTED_FACE\x10\xba@\x12(\n#CAMERA_NOTIFICATION_DARK_EIS_STATUS\x10\xbc@\x12\x39\n4CAMERA_NOTIFICATION_SUPPORT_TAKE_PHOTO_ON_REC_STATUS\x10\xc0@\x12&\n!PHONE_COMMAND_STOP_USBCARD_BACKUP\x10\x85\x01\x12)\n$PHONE_COMMAND_QUICKREADER_GET_STATUS\x10\xb6\x01\x12\'\n"CAMERA_NOTIFICATION_USBCARD_STATUS\x10\xb2@\x12+\n&CAMERA_NOTIFICATION_NEED_DOWNLOAD_FILE\x10\xc3@\x12+\n&CAMERA_NOTIFICATION_CAM_SUBMODE_CHANGE\x10\xd3@\x12/\n*CAMERA_NOTIFICATION_FAVORITE_CHANGE_STATUS\x10\xdc@\x12\x1f\n\x1aPHONE_COMMAND_SET_FAVORITE\x10\xb0\x01\x12\x32\n-CAMERA_NOTIFICATION_CLOUD_STORAGE_BIND_STATUS\x10\xbf@\x12&\n!CAMERA_NOTIFICATION_USER_TAKEOVER\x10\xdd@\x12\x1a\n\x15\x46\x41\x43TORY_COMMAND_BEGIN\x10\x80`\x12\x1e\n\x19\x46\x41\x43TORY_COMMAND_OLED_TEST\x10\x81`\x12\x1d\n\x18\x46\x41\x43TORY_COMMAND_LED_TEST\x10\x82`\x12!\n\x1c\x46\x41\x43TORY_COMMAND_SPEAKER_TEST\x10\x83`\x12"\n\x1d\x46\x41\x43TORY_COMMAND_OLED_ROW_EVEN\x10\x84`\x12$\n\x1f\x46\x41\x43TORY_COMMAND_OLED_ROW_UNEVEN\x10\x85`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_OLED_LINE_EVEN\x10\x86`\x12%\n FACTORY_COMMAND_OLED_LINE_UNEVEN\x10\x87`\x12%\n FACTORY_COMMAND_WIFI_STATUS_TEST\x10\x88`\x12*\n%FACTORY_COMMAND_BLUETOOTH_STATUS_TEST\x10\x89`\x12\x1f\n\x1a\x46\x41\x43TORY_COMMAND_MOTOR_TEST\x10\x8a`\x12\'\n"FACTORY_COMMAND_WHITE_BALANCE_TEST\x10\x8b`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_GYROSCOPE_TEST\x10\x8c`\x12"\n\x1d\x46\x41\x43TORY_COMMAND_LED_TEST_STOP\x10\x8d`\x12$\n\x1f\x46\x41\x43TORY_COMMAND_MOTOR_TEST_STOP\x10\x8e`\x12.\n)FACTORY_COMMAND_WHITE_BALANCE_STATUS_TEST\x10\x8f`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_FW_AGEING_TEST\x10\x90`\x12\'\n"FACTORY_COMMAND_BUTTON_STATUS_TEST\x10\x91`\x12&\n!FACTORY_COMMAND_TP_JIUGONGGE_TEST\x10\x92`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_LCD_COLOR_TEST\x10\x93`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_USB_SPEED_TEST\x10\x94`\x12*\n%FACTORY_COMMAND_USB_LCD_TP_CLOSE_TEST\x10\x95`\x12\'\n"FACTORY_COMMAND_VIGNETTE_DATA_SAVE\x10\x96`\x12"\n\x1d\x46\x41\x43TORY_COMMAND_BLC_DATA_SAVE\x10\x97`\x12"\n\x1d\x46\x41\x43TORY_COMMAND_BPC_DATA_SAVE\x10\x98`\x12\x1f\n\x1a\x46\x41\x43TORY_COMMAND_PLAY_AUDIO\x10\x99`\x12\x1f\n\x1a\x46\x41\x43TORY_COMMAND_STOP_AUDIO\x10\xa0`\x12\'\n"FACTORY_COMMAND_RECORD_AUDIO_START\x10\xa1`\x12&\n!FACTORY_COMMAND_RECORD_AUDIO_STOP\x10\xa2`\x12!\n\x1c\x46\x41\x43TORY_COMMAND_DEVLINK_TEST\x10\xa3`\x12*\n%FACTORY_COMMAND_GET_AGEINGTEST_STATUS\x10\xa4`\x12(\n#FACTORY_COMMAND_LCD_COLOR_TEST_STOP\x10\xa5`\x12-\n(FACTORY_COMMAND_LCD_COLOR_TEST_COLOR_SET\x10\xa6`\x12+\n&FACTORY_COMMAND_BUTTON_HANDLER_REFRESH\x10\xa7`\x12)\n$FACTORY_COMMAND_OLED_CORRECTION_EVEN\x10\xa8`\x12+\n&FACTORY_COMMAND_OLED_CORRECTION_UNEVEN\x10\xa9`\x12\x34\n/FACTORY_COMMAND_OLED_CORRECTION_SET_OFFSET_TEST\x10\xaa`\x12\x34\n/FACTORY_COMMAND_OLED_CORRECTION_GET_OFFSET_TEST\x10\xab`\x12 \n\x1b\x46\x41\x43TORY_COMMAND_CHARGINGBOX\x10\xac`\x12,\n\'FACTORY_COMMAND_CHARGINGBOX_BUTTON_TEST\x10\xad`\x12*\n%FACTORY_COMMAND_CHARGINGBOX_HALL_TEST\x10\xae`\x12\'\n"FACTORY_COMMAND_SCRIPT_JSON_UPLOAD\x10\xaf`\x12&\n!FACTORY_COMMAND_SCRIPT_CMD_UPLOAD\x10\xb0`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_SCRIPT_REFRESH\x10\xb1`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_SCRIPT_CMD_RUN\x10\xb2`\x12(\n#FACTORY_COMMAND_SET_AAA_FACTORYMODE\x10\xb3`\x12\'\n"FACTORY_COMMAND_SET_AAA_NORMALMODE\x10\xb4`\x12+\n&FACTORY_COMMAND_GET_WHITEBLANCE_STATUS\x10\xb5`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_GET_SFR_STATUS\x10\xb6`\x12#\n\x1e\x46\x41\x43TORY_COMMAND_GET_SFR_RESULT\x10\xb7`\x12\x32\n-PHONE_COMMAND_GET_CLOUD_STORAGE_UPLOAD_STATUS\x10\xa0\x01\x12\x32\n-PHONE_COMMAND_SET_CLOUD_STORAGE_UPLOAD_STATUS\x10\xa1\x01\x12\x30\n+PHONE_COMMAND_GET_CLOUD_STORAGE_BIND_STATUS\x10\xa2\x01\x12\x30\n+PHONE_COMMAND_SET_CLOUD_STORAGE_BIND_STATUS\x10\xa3\x01\x12(\n#PHONE_COMMAND_DEL_WIFI_HISTORY_INFO\x10\xaf\x01\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "message_code_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_MESSAGECODE"]._serialized_start = 42
    _globals["_MESSAGECODE"]._serialized_end = 8300
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: charging_command_type.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x1b\x63harging_command_type.proto\x12\x11insta360.messages*\xb9\x02\n\x13\x43hargingMessageCode\x12\x11\n\rFAC_OLED_TEST\x10\x00\x12\x15\n\x11\x46\x41\x43_OLED_ROW_EVEN\x10\x01\x12\x17\n\x13\x46\x41\x43_OLED_ROW_UNEVEN\x10\x02\x12\x16\n\x12\x46\x41\x43_OLED_LINE_EVEN\x10\x03\x12\x18\n\x14\x46\x41\x43_OLED_LINE_UNEVEN\x10\x04\x12\x10\n\x0c\x46\x41\x43_LED_TEST\x10\x05\x12\x14\n\x10\x46\x41\x43_DEVLINK_TEST\x10\x06\x12\x13\n\x0f\x46\x41\x43_BUTTON_TEST\x10\x07\x12\x1b\n\x17\x46\x41\x43_NORMAL_MODE_REFRESH\x10\x08\x12\x11\n\rFAC_HALL_TEST\x10\t\x12\x16\n\x12\x46\x41\x43_BLUETOOTH_TEST\x10\x10\x12\x1b\n\x17\x46\x41\x43_BLUETOOTH_WKUP_TEST\x10\x11\x12\x0b\n\x07\x46\x41\x43_NUM\x10\x12\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "charging_command_type_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_CHARGINGMESSAGECODE"]._serialized_start = 51
    _globals["_CHARGINGMESSAGECODE"]._serialized_end = 364
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_appid.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0fset_appid.proto\x12\x11insta360.messages"\x19\n\x08SetAppid\x12\r\n\x05\x61ppid\x18\x01 \x01(\t"\x0e\n\x0cSetAppidRespB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_appid_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETAPPID"]._serialized_start = 38
    _globals["_SETAPPID"]._serialized_end = 63
    _globals["_SETAPPIDRESP"]._serialized_start = 65
    _globals["_SETAPPIDRESP"]._serialized_end = 79
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: get_wifi_connection_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from wifi_connection_info_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1eget_wifi_connection_info.proto\x12\x11insta360.messages\x1a\x1awifi_connection_info.proto"\x17\n\x15GetWifiConnectionInfo"`\n\x19GetWifiConnectionInfoResp\x12\x43\n\x14wifi_connection_info\x18\x01 \x01(\x0b\x32%.insta360.messages.WifiConnectionInfoB\x08\xa2\x02\x05INSPBP\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "get_wifi_connection_info_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_GETWIFICONNECTIONINFO"]._serialized_start = 81
    _globals["_GETWIFICONNECTIONINFO"]._serialized_end = 104
    _globals["_GETWIFICONNECTIONINFORESP"]._serialized_start = 106
    _globals["_GETWIFICONNECTIONINFORESP"]._serialized_end = 202
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: media.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0bmedia.proto\x12\x11insta360.messages"<\n\x03GPS\x12\x11\n\tlongitude\x18\x01 \x01(\x01\x12\x10\n\x08latitude\x18\x02 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x03 \x01(\x01"N\n\x04Gyro\x12\n\n\x02\x61x\x18\x01 \x01(\x01\x12\n\n\x02\x61y\x18\x02 \x01(\x01\x12\n\n\x02\x61z\x18\x03 \x01(\x01\x12\n\n\x02gx\x18\x04 \x01(\x01\x12\n\n\x02gy\x18\x05 \x01(\x01\x12\n\n\x02gz\x18\x06 \x01(\x01"9\n\x0bOrientation\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\t\n\x01z\x18\x03 \x01(\x05\x12\t\n\x01w\x18\x04 \x01(\x05*\x1e\n\tAACBSType\x12\x07\n\x03RAW\x10\x00\x12\x08\n\x04\x41\x44TS\x10\x01*_\n\tMediaType\x12\t\n\x05VIDEO\x10\x00\x12\t\n\x05PHOTO\x10\x01\x12\x13\n\x0fVIDEO_AND_PHOTO\x10\x02\x12\x07\n\x03\x44NG\x10\x03\x12\x07\n\x03MP4\x10\x04\x12\x07\n\x03JPG\x10\x05\x12\x0c\n\x08INS_DATA\x10\x06\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "media_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_AACBSTYPE"]._serialized_start = 235
    _globals["_AACBSTYPE"]._serialized_end = 265
    _globals["_MEDIATYPE"]._serialized_start = 267
    _globals["_MEDIATYPE"]._serialized_end = 362
    _globals["_GPS"]._serialized_start = 34
    _globals["_GPS"]._serialized_end = 94
    _globals["_GYRO"]._serialized_start = 96
    _globals["_GYRO"]._serialized_end = 174
    _globals["_ORIENTATION"]._serialized_start = 176
    _globals["_ORIENTATION"]._serialized_end = 233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: set_favorite.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12set_favorite.proto\x12\x11insta360.messages"l\n\x0bSetFavorite\x12\x16\n\x0ematerial_index\x18\x01 \x01(\r\x12\x15\n\rfavorite_flag\x18\x02 \x01(\r\x12\x14\n\x0cmaterial_url\x18\x03 \x01(\t\x12\x18\n\x10modify_timestamp\x18\x04 \x01(\x03"G\n\x0fSetFavoriteList\x12\x34\n\x0cset_favorite\x18\x01 \x03(\x0b\x32\x1e.insta360.messages.SetFavorite"d\n\x13MaterialFavoriteReq\x12\x10\n\x08\x63md_type\x18\x01 \x01(\r\x12\x13\n\x0bindex_start\x18\x02 \x01(\r\x12\x11\n\tindex_end\x18\x03 \x01(\r\x12\x13\n\x0bis_end_flag\x18\x04 \x01(\x08"S\n\x14MaterialFavoriteResp\x12\x10\n\x08\x63md_type\x18\x01 \x01(\r\x12\x13\n\x0bis_end_flag\x18\x02 \x01(\x08\x12\x14\n\x0cmaterial_num\x18\x03 \x01(\rB\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "set_favorite_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_SETFAVORITE"]._serialized_start = 41
    _globals["_SETFAVORITE"]._serialized_end = 149
    _globals["_SETFAVORITELIST"]._serialized_start = 151
    _globals["_SETFAVORITELIST"]._serialized_end = 222
    _globals["_MATERIALFAVORITEREQ"]._serialized_start = 224
    _globals["_MATERIALFAVORITEREQ"]._serialized_end = 324
    _globals["_MATERIALFAVORITERESP"]._serialized_start = 326
    _globals["_MATERIALFAVORITERESP"]._serialized_end = 409
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: interval_rec_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x17interval_rec_info.proto\x12\x11insta360.messages\"\xe4\x01\n\x0fIntervalRecInfo\x12\x0f\n\x07\x62\x45nable\x18\x01 \x01(\r\x12\x12\n\ntotalCount\x18\x02 \x01(\r\x12\x0c\n\x04mode\x18\x03 \x01(\r\x12\x14\n\x0cintervalTime\x18\x04 \x01(\r\x12\x11\n\tstartTime\x18\x05 \x01(\r\x12\x11\n\tshotCount\x18\x06 \x01(\r\x12:\n\ttoastType\x18\x07 \x01(\x0e\x32'.insta360.messages.IntervalRecToastType\x12\x10\n\x08stopCase\x18\x08 \x01(\r\x12\x14\n\x0csum_duration\x18\t \x01(\r*\xc6\x02\n\x14IntervalRecToastType\x12\x1b\n\x17INTERVAL_REC_TOAST_NULL\x10\x00\x12\x1c\n\x18INTERVAL_REC_TOAST_START\x10\x01\x12\x1f\n\x1bINTERVAL_REC_TOAST_AUTO_END\x10\x02\x12!\n\x1dINTERVAL_REC_TOAST_MANUAL_END\x10\x03\x12\x1d\n\x19INTERVAL_REC_TOAST_CANCEL\x10\x04\x12 \n\x1cINTERVAL_REC_TOAST_OTHER_END\x10\x05\x12#\n\x1fINTERVAL_REC_TOAST_INTERVAL_REC\x10\x06\x12\x1f\n\x1bINTERVAL_REC_TOAST_CONFLICT\x10\x07\x12(\n$INTERVAL_REC_TOAST_AUTO_END_WITH_APP\x10\x08\x42\x08\xa2\x02\x05INSPBb\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "interval_rec_info_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_INTERVALRECTOASTTYPE"]._serialized_start = 278
    _globals["_INTERVALRECTOASTTYPE"]._serialized_end = 604
    _globals["_INTERVALRECINFO"]._serialized_start = 47
    _globals["_INTERVALRECINFO"]._serialized_end = 275
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: photo.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0bphoto.proto\x12\x11insta360.messages"<\n\x05Photo\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x04\x12\x13\n\x0bs_thumbnail\x18\x03 \x01(\x0c*\x90\x02\n\tPhotoSize\x12\x12\n\x0eSize_6912_3456\x10\x00\x12\x12\n\x0eSize_6272_3136\x10\x01\x12\x12\n\x0eSize_6080_3040\x10\x02\x12\x12\n\x0eSize_4000_3000\x10\x03\x12\x12\n\x0eSize_4000_2250\x10\x04\x12\x12\n\x0eSize_5212_3542\x10\x05\x12\x12\n\x0eSize_5312_2988\x10\x06\x12\x12\n\x0eSize_8000_6000\x10\x07\x12\x12\n\x0eSize_8000_4500\x10\x08\x12\x12\n\x0eSize_2976_2976\x10\t\x12\x12\n\x0eSize_5984_5984\x10\n\x12\x13\n\x0fSize_11968_5984\x10\x0b\x12\x12\n\x0eSize_5952_2976\x10\x0c*\xbe\x01\n\x0cPhotoSubMode\x12\x10\n\x0cPHOTO_SINGLE\x10\x00\x12\r\n\tPHOTO_HDR\x10\x01\x12\x12\n\x0ePHOTO_INTERVAL\x10\x02\x12\x0f\n\x0bPHOTO_BURST\x10\x03\x12\x13\n\x0fPHOTO_AEB_NIGHT\x10\x04\x12\x14\n\x10PHOTO_INSTA_PANO\x10\x05\x12\x18\n\x14PHOTO_INSTA_PANO_HDR\x10\x06\x12\x13\n\x0fPHOTO_STARLAPSE\x10\x07\x12\x0e\n\nPHOTO_NONE\x10\x64*\xda\x01\n\x0eRawCaptureType\x12\x18\n\x14RAW_CAPTURE_TYPE_OFF\x10\x00\x12\x18\n\x14RAW_CAPTURE_TYPE_DNG\x10\x01\x12\x18\n\x14RAW_CAPTURE_TYPE_RAW\x10\x02\x12\x1d\n\x19RAW_CAPTURE_TYPE_PURESHOT\x10\x03\x12!\n\x1dRAW_CAPTURE_TYPE_PURESHOT_RAW\x10\x04\x12\x19\n\x15RAW_CAPTURE_TYPE_INSP\x10\x05\x12\x1d\n\x19RAW_CAPTURE_TYPE_INSP_RAW\x10\x06\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "photo_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_PHOTOSIZE"]._serialized_start = 97
    _globals["_PHOTOSIZE"]._serialized_end = 369
    _globals["_PHOTOSUBMODE"]._serialized_start = 372
    _globals["_PHOTOSUBMODE"]._serialized_end = 562
    _globals["_RAWCAPTURETYPE"]._serialized_start = 565
    _globals["_RAWCAPTURETYPE"]._serialized_end = 783
    _globals["_PHOTO"]._serialized_start = 34
    _globals["_PHOTO"]._serialized_end = 94
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: photography_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from video_pb2 import *
from photo_pb2 import *
from flicker_pb2 import *
from exposure_pb2 import *
from sensor_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19photography_options.proto\x12\x11insta360.messages\x1a\x0bvideo.proto\x1a\x0bphoto.proto\x1a\rflicker.proto\x1a\x0e\x65xposure.proto\x1a\x0csensor.proto"\x81,\n\x12PhotographyOptions\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\r\x12\x12\n\nbrightness\x18\x02 \x01(\x11\x12\x10\n\x08\x63ontrast\x18\x03 \x01(\r\x12\x12\n\nsaturation\x18\x04 \x01(\r\x12\x0b\n\x03hue\x18\x05 \x01(\x11\x12\x11\n\tsharpness\x18\x06 \x01(\r\x12\x15\n\rexposure_bias\x18\x07 \x01(\x11\x12I\n\rexposure_mode\x18\x08 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ExposureMode\x12I\n\rexposure_prog\x18\t \x01(\x0b\x32\x32.insta360.messages.PhotographyOptions.ExposureProg\x12M\n\x0f\x65xposure_manual\x18\n \x01(\x0b\x32\x34.insta360.messages.PhotographyOptions.ExposureManual\x12\x45\n\nmeter_mode\x18\x0b \x01(\x0e\x32\x31.insta360.messages.PhotographyOptions.AEMeterMode\x12\x1c\n\x14manual_meter_weights\x18\x0c \x03(\r\x12I\n\rwhite_balance\x18\r \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.WhiteBalance\x12+\n\x07\x66licker\x18\x0e \x01(\x0e\x32\x1a.insta360.messages.Flicker\x12\x10\n\x08\x65v_index\x18\x0f \x01(\r\x12V\n\x15\x61uto_mode_video_param\x18\x10 \x01(\x0b\x32\x37.insta360.messages.PhotographyOptions.ExposureParameter\x12V\n\x15\x61uto_mode_still_param\x18\x11 \x01(\x0b\x32\x37.insta360.messages.PhotographyOptions.ExposureParameter\x12\x30\n\ngamma_mode\x18\x12 \x01(\x0e\x32\x1c.insta360.messages.GammaMode\x12V\n\x14long_exposure_manual\x18\x13 \x01(\x0b\x32\x38.insta360.messages.PhotographyOptions.LongExposureManual\x12:\n\x0estill_exposure\x18\x14 \x01(\x0b\x32".insta360.messages.ExposureOptions\x12:\n\x0evideo_exposure\x18\x15 \x01(\x0b\x32".insta360.messages.ExposureOptions\x12\x1b\n\x13preview_mctf_enable\x18\x16 \x01(\x08\x12!\n\x19preview_sport_mode_enable\x18\x17 \x01(\x08\x12\x1b\n\x13video_iso_top_limit\x18\x18 \x01(\r\x12;\n\x10raw_capture_type\x18\x19 \x01(\x0e\x32!.insta360.messages.RawCaptureType\x12\x1e\n\x16photography_self_timer\x18\x1a \x01(\r\x12\x17\n\x0f\x61\x65\x62_capture_num\x18\x1b \x01(\r\x12V\n\x13preview_sport_level\x18\x1c \x01(\x0e\x32\x39.insta360.messages.PhotographyOptions.PREVIEW_SPORT_LEVEL\x12\x17\n\x0frecord_duration\x18\x1d \x01(\r\x12\x15\n\rphoto_size_id\x18\x1e \x01(\r\x12=\n\x11record_resolution\x18\x1f \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x15\n\rvideo_bitrate\x18  \x01(\r\x12,\n\x08\x66ov_type\x18! \x01(\x0e\x32\x1a.insta360.messages.FovType\x12\x1d\n\x15\x66lowstate_base_enable\x18" \x01(\x08\x12\x44\n\ncolor_mode\x18# \x01(\x0e\x32\x30.insta360.messages.PhotographyOptions.COLOR_MODE\x12H\n\rres_rec_limit\x18$ \x03(\x0b\x32\x31.insta360.messages.PhotographyOptions.ResRecLimit\x12\x1c\n\x14\x61\x63\x63\x65lerate_frequency\x18% \x01(\r\x12\x1a\n\x12\x66ocal_length_value\x18& \x01(\x01\x12\x1b\n\x13white_balance_value\x18\' \x01(\r\x12\x36\n\x10photo_resolution\x18( \x01(\x0e\x32\x1c.insta360.messages.PhotoSize\x12\x16\n\x0eremaining_time\x18) \x01(\r\x12\x17\n\x0f\x64\x61rk_eis_enable\x18* \x01(\x08\x12P\n\x10\x66low_state_level\x18+ \x01(\x0e\x32\x36.insta360.messages.PhotographyOptions.Flow_State_Level\x12\x19\n\x11\x62urst_capture_num\x18, \x01(\r\x12\x19\n\x11\x63\x61\x63he_capture_num\x18- \x01(\r\x12\x17\n\x0fmetering_enable\x18. \x01(\x08\x12\x1a\n\x12\x62urst_capture_time\x18\x33 \x01(\r\x12\x1c\n\x14\x63\x61\x63he_capture_enable\x18\x34 \x01(\x08\x12\x12\n\nzoom_scale\x18\x35 \x01(\x01\x12\x14\n\x0cmax_rec_time\x18\x36 \x01(\r\x12^\n\x17\x66low_state_level_by_cv5\x18\x37 \x01(\x0e\x32=.insta360.messages.PhotographyOptions.Flow_State_Level_By_Cv5\x12Y\n\x14starlasp_export_type\x18\x38 \x01(\x0e\x32;.insta360.messages.PhotographyOptions.StarLapse_Export_Type\x12#\n\x1bvideo_flowstate_base_enable\x18: \x01(\x08\x12\x1a\n\x12\x64ouble_zoom_enable\x18; \x01(\x08\x12T\n\x12pano_exposure_mode\x18= \x01(\x0e\x32\x38.insta360.messages.PhotographyOptions.Pano_Exposure_Mode\x12L\n\x0bselfie_mode\x18> \x01(\x0e\x32\x37.insta360.messages.PhotographyOptions.VIDEO_SELFIE_MODE\x12\x19\n\x11hdr_switch_status\x18? \x01(\x08\x12\\\n\x18\x66lowstate_horizon_enable\x18\x46 \x01(\x0e\x32:.insta360.messages.PhotographyOptions.FlowStateHorizonType\x1a\x80\x02\n\x0c\x45xposureProg\x12I\n\x04mode\x18\x01 \x01(\x0e\x32;.insta360.messages.PhotographyOptions.ExposureProg.ProgMode\x12\x0b\n\x03iso\x18\x02 \x01(\r\x12I\n\rshutter_speed\x18\x03 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed"M\n\x08ProgMode\x12\x11\n\rPROG_MODE_OFF\x10\x00\x12\x11\n\rPROG_MODE_ISO\x10\x01\x12\x1b\n\x17PROG_MODE_SHUTTER_SPEED\x10\x02\x1a\xe3\x03\n\x0e\x45xposureManual\x12T\n\x0brelate_mode\x18\x01 \x01(\x0e\x32?.insta360.messages.PhotographyOptions.ExposureManual.RelateMode\x12\x0b\n\x03iso\x18\x02 \x01(\r\x12I\n\rshutter_speed\x18\x03 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed\x12\x11\n\tvideo_iso\x18\x04 \x01(\r\x12O\n\x13video_shutter_speed\x18\x05 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed\x12\x11\n\tstill_iso\x18\x06 \x01(\r\x12O\n\x13still_shutter_speed\x18\x07 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed"[\n\nRelateMode\x12\x15\n\x11RELATE_MODE_VIDEO\x10\x00\x12\x15\n\x11RELATE_MODE_STILL\x10\x01\x12\x1f\n\x1bRELATE_MODE_VIDEO_AND_STILL\x10\x02\x1ak\n\x11\x45xposureParameter\x12\x0b\n\x03iso\x18\x01 \x01(\r\x12I\n\rshutter_speed\x18\x02 \x01(\x0e\x32\x32.insta360.messages.PhotographyOptions.ShutterSpeed\x1a\x38\n\x12LongExposureManual\x12\x0b\n\x03iso\x18\x01 \x01(\r\x12\x15\n\rshutter_speed\x18\x02 \x01(\r\x1aX\n\x0bResRecLimit\x12\x35\n\tvideo_res\x18\x01 \x01(\x0e\x32".insta360.messages.VideoResolution\x12\x12\n\nlimit_time\x18\x02 \x01(\r"L\n\x0c\x45xposureMode\x12\x11\n\rEXP_MODE_AUTO\x10\x00\x12\x14\n\x10\x45XP_MODE_PROGRAM\x10\x01\x12\x13\n\x0f\x45XP_MODE_MANUAL\x10\x02"A\n\x0b\x41\x45MeterMode\x12\x18\n\x14\x41\x45_METER_MODE_NORMAL\x10\x00\x12\x18\n\x14\x41\x45_METER_MODE_MANUAL\x10\x01"a\n\x0cWhiteBalance\x12\x0b\n\x07WB_AUTO\x10\x00\x12\x0c\n\x08WB_2700K\x10\x01\x12\x0c\n\x08WB_4000K\x10\x02\x12\x0c\n\x08WB_5000K\x10\x03\x12\x0c\n\x08WB_6500K\x10\x04\x12\x0c\n\x08WB_7500K\x10\x05"_\n\x13PREVIEW_SPORT_LEVEL\x12\x16\n\x12PREVIEW_SPORT_AUTO\x10\x00\x12\x16\n\x12PREVIEW_SPORT_FAST\x10\x01\x12\x18\n\x14PREVIEW_SPORT_FASTER\x10\x02"a\n\nCOLOR_MODE\x12\x15\n\x11\x43OLOR_MODE_NORMAL\x10\x00\x12\x12\n\x0e\x43OLOR_MODE_LOG\x10\x01\x12\x14\n\x10\x43OLOR_MODE_VIVID\x10\x02\x12\x12\n\x0e\x43OLOR_MODE_HDR\x10\x03"\x82\x01\n\x10\x46low_State_Level\x12\x1a\n\x16\x46low_State_Level_Close\x10\x00\x12\x18\n\x14\x46low_State_Level_Low\x10\x01\x12\x1d\n\x19\x46low_State_Level_Standard\x10\x02\x12\x19\n\x15\x46LOW_State_Level_High\x10\x03"\x9d\x01\n\x17\x46low_State_Level_By_Cv5\x12\x1e\n\x1a\x46low_State_Level_CV5_Close\x10\x00\x12\x1f\n\x1b\x46LOW_State_Level_CV5_Slight\x10\x01\x12 \n\x1c\x46LOW_State_Level_CV5_General\x10\x02\x12\x1f\n\x1b\x46LOW_State_Level_CV5_Strong\x10\x03"Z\n\x15StarLapse_Export_Type\x12\x13\n\x0fStarLapse_Video\x10\x00\x12\x15\n\x11Star_Trails_Video\x10\x01\x12\x15\n\x11Star_Trails_Photo\x10\x02"o\n\x12Pano_Exposure_Mode\x12\x1a\n\x16Pano_Exposure_Mode_Off\x10\x00\x12\x1c\n\x18Pano_Exposure_Mode_Light\x10\x01\x12\x1f\n\x1bPano_Exposure_Mode_Lsolated\x10\x02"?\n\x11VIDEO_SELFIE_MODE\x12\r\n\tMODE_NONE\x10\x00\x12\x0b\n\x07ME_MODE\x10\x01\x12\x0e\n\nTORCH_MODE\x10\x02"r\n\x14\x46lowStateHorizonType\x12\x1e\n\x1a\x46LOW_STATE_HORIZON_DISABLE\x10\x00\x12\x1d\n\x19\x46LOW_STATE_HORIZON_ENABLE\x10\x01\x12\x1b\n\x17\x46LOW_STATE_HORIZON_AUTO\x10\x02"\xad\x06\n\x0cShutterSpeed\x12\x0e\n\nSPEED_AUTO\x10\x00\x12\x0c\n\x08SPEED_60\x10\x01\x12\x0c\n\x08SPEED_30\x10\x02\x12\x0c\n\x08SPEED_15\x10\x03\x12\x0b\n\x07SPEED_8\x10\x04\x12\x0b\n\x07SPEED_4\x10\x05\x12\x0b\n\x07SPEED_2\x10\x06\x12\r\n\tSPEED_1P6\x10\x07\x12\r\n\tSPEED_1P3\x10\x08\x12\x0b\n\x07SPEED_1\x10\t\x12\x10\n\x0cSPEED_1D1P25\x10\n\x12\x10\n\x0cSPEED_1D1P67\x10\x0b\x12\r\n\tSPEED_1D2\x10\x0c\x12\x0f\n\x0bSPEED_1D2P5\x10\r\x12\r\n\tSPEED_1D3\x10\x0e\x12\r\n\tSPEED_1D4\x10\x0f\x12\r\n\tSPEED_1D5\x10\x10\x12\x10\n\x0cSPEED_1D6P25\x10\x11\x12\x0e\n\nSPEED_1D8P\x10\x12\x12\x0e\n\nSPEED_1D10\x10\x13\x12\x10\n\x0cSPEED_1D12P5\x10\x14\x12\x0e\n\nSPEED_1D15\x10\x15\x12\x0e\n\nSPEED_1D20\x10\x16\x12\x0e\n\nSPEED_1D25\x10\x17\x12\x0e\n\nSPEED_1D30\x10\x18\x12\x0e\n\nSPEED_1D40\x10\x19\x12\x0e\n\nSPEED_1D50\x10\x1a\x12\x0e\n\nSPEED_1D60\x10\x1b\x12\x0e\n\nSPEED_1D80\x10\x1c\x12\x0f\n\x0bSPEED_1D100\x10\x1d\x12\x0f\n\x0bSPEED_1D120\x10\x1e\x12\x0f\n\x0bSPEED_1D160\x10\x1f\x12\x0f\n\x0bSPEED_1D200\x10 \x12\x0f\n\x0bSPEED_1D240\x10!\x12\x0f\n\x0bSPEED_1D320\x10"\x12\x0f\n\x0bSPEED_1D400\x10#\x12\x0f\n\x0bSPEED_1D500\x10$\x12\x0f\n\x0bSPEED_1D640\x10%\x12\x0f\n\x0bSPEED_1D800\x10&\x12\x10\n\x0cSPEED_1D1000\x10\'\x12\x10\n\x0cSPEED_1D1250\x10(\x12\x10\n\x0cSPEED_1D1600\x10)\x12\x10\n\x0cSPEED_1D2000\x10*\x12\x10\n\x0cSPEED_1D2500\x10+\x12\x10\n\x0cSPEED_1D3200\x10,\x12\x10\n\x0cSPEED_1D4000\x10-\x12\x10\n\x0cSPEED_1D5000\x10.\x12\x10\n\x0cSPEED_1D6400\x10/\x12\x10\n\x0cSPEED_1D8000\x10\x30*\xca\n\n\x15PhotographyOptionType\x12\x1e\n\x1aPHOTOGRAPHY_OPTION_UNKNOWN\x10\x00\x12\x0b\n\x07\x43HANNEL\x10\x01\x12\x0e\n\nBRIGHTNESS\x10\x02\x12\x0c\n\x08\x43ONTRAST\x10\x03\x12\x0e\n\nSATURATION\x10\x04\x12\x07\n\x03HUE\x10\x05\x12\r\n\tSHARPNESS\x10\x06\x12\x11\n\rEXPOSURE_BIAS\x10\x07\x12\x11\n\rEXPOSURE_MODE\x10\x08\x12\x11\n\rEXPOSURE_PROG\x10\t\x12\x13\n\x0f\x45XPOSURE_MANUAL\x10\n\x12\x11\n\rAE_METER_MODE\x10\x0b\x12\x1a\n\x16\x41\x45_MANUAL_METER_WEIGHT\x10\x0c\x12\x11\n\rWHITE_BALANCE\x10\r\x12\x0b\n\x07\x46LICKER\x10\x0e\x12\x0c\n\x08\x45V_INDEX\x10\x0f\x12\x19\n\x15\x41UTO_MODE_VIDEO_PARAM\x10\x10\x12\x19\n\x15\x41UTO_MODE_STILL_PARAM\x10\x11\x12\x14\n\x10VIDEO_GAMMA_MODE\x10\x12\x12\x18\n\x14LONG_EXPOSURE_MANUAL\x10\x13\x12\x1a\n\x16STILL_EXPOSURE_OPTIONS\x10\x14\x12\x1a\n\x16VIDEO_EXPOSURE_OPTIONS\x10\x15\x12\x17\n\x13PREVIEW_MCTF_ENABLE\x10\x16\x12\x1d\n\x19PREVIEW_SPORT_MODE_ENABLE\x10\x17\x12\x17\n\x13VIDEO_ISO_TOP_LIMIT\x10\x18\x12\x14\n\x10RAW_CAPTURE_TYPE\x10\x19\x12\x1a\n\x16PHOTOGRAPHY_SELF_TIMER\x10\x1a\x12\x13\n\x0f\x41\x45\x42_CAPTURE_NUM\x10\x1b\x12\x17\n\x13PREVIEW_SPORT_LEVEL\x10\x1c\x12\x12\n\x0eRECORD_DURAION\x10\x1d\x12\x11\n\rPHOTO_SIZE_ID\x10\x1e\x12\x15\n\x11RECORD_RESOLUTION\x10\x1f\x12\x18\n\x14PHOTO_GRAPHY_BITRATE\x10 \x12\x0c\n\x08\x46OV_TYPE\x10!\x12\x17\n\x13\x46LOWSTATE_BASE_TYPE\x10"\x12\x0e\n\nCOLOR_MODE\x10#\x12\x11\n\rRES_REC_LIMIT\x10$\x12\x18\n\x14\x41\x43\x43\x45LERATE_FREQUENCY\x10%\x12\x16\n\x12\x46OCAL_LENGTH_VALUE\x10&\x12\x17\n\x13WHITE_BALANCE_VALUE\x10\'\x12\x14\n\x10PHOTO_RESOLUTION\x10(\x12\x12\n\x0eREMAINING_TIME\x10)\x12\x13\n\x0f\x44\x41RK_EIS_ENABLE\x10*\x12\x13\n\x0f\x46LOWSTATE_LEVEL\x10+\x12\x15\n\x11\x42URST_CAPTURE_NUM\x10,\x12\x15\n\x11\x43\x41\x43HE_CAPTURE_NUM\x10-\x12\x13\n\x0fMETERING_ENABLE\x10.\x12\x16\n\x12\x42URST_CAPTURE_TIME\x10\x33\x12\x18\n\x14\x43\x41\x43HE_CAPTURE_ENABLE\x10\x34\x12\x0e\n\nZOOM_SCALE\x10\x35\x12\x10\n\x0cMAX_REC_TIME\x10\x36\x12\x1a\n\x16\x46LOWSTATE_LEVEL_BY_CV5\x10\x37\x12\x19\n\x15STARLAPSE_EXPORT_TYPE\x10\x38\x12\x1d\n\x19VIDEO_FLOWSTATE_BASE_TYPE\x10:\x12\x0f\n\x0b\x44OUBLE_ZOOM\x10;\x12\x16\n\x12PANO_EXPOSURE_MODE\x10=\x12\x15\n\x11VIDEO_SELFIE_MODE\x10>\x12\x15\n\x11HDR_SWITCH_STATUS\x10?\x12\x1c\n\x18\x46LOWSTATE_HORIZON_ENABLE\x10\x46\x12!\n\x1dPHOTO_GRAPHY_OPTIONS_TYPE_NUM\x10GB\x08\xa2\x02\x05INSPBP\x00P\x01P\x02P\x03P\x04\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "photography_options_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_PHOTOGRAPHYOPTIONTYPE"]._serialized_start = 5756
    _globals["_PHOTOGRAPHYOPTIONTYPE"]._serialized_end = 7110
    _globals["_PHOTOGRAPHYOPTIONS"]._serialized_start = 120
    _globals["_PHOTOGRAPHYOPTIONS"]._serialized_end = 5753
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPROG"]._serialized_start = 2819
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPROG"]._serialized_end = 3075
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPROG_PROGMODE"]._serialized_start = 2998
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPROG_PROGMODE"]._serialized_end = 3075
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMANUAL"]._serialized_start = 3078
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMANUAL"]._serialized_end = 3561
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMANUAL_RELATEMODE"]._serialized_start = 3470
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMANUAL_RELATEMODE"]._serialized_end = 3561
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPARAMETER"]._serialized_start = 3563
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREPARAMETER"]._serialized_end = 3670
    _globals["_PHOTOGRAPHYOPTIONS_LONGEXPOSUREMANUAL"]._serialized_start = 3672
    _globals["_PHOTOGRAPHYOPTIONS_LONGEXPOSUREMANUAL"]._serialized_end = 3728
    _globals["_PHOTOGRAPHYOPTIONS_RESRECLIMIT"]._serialized_start = 3730
    _globals["_PHOTOGRAPHYOPTIONS_RESRECLIMIT"]._serialized_end = 3818
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMODE"]._serialized_start = 3820
    _globals["_PHOTOGRAPHYOPTIONS_EXPOSUREMODE"]._serialized_end = 3896
    _globals["_PHOTOGRAPHYOPTIONS_AEMETERMODE"]._serialized_start = 3898
    _globals["_PHOTOGRAPHYOPTIONS_AEMETERMODE"]._serialized_end = 3963
    _globals["_PHOTOGRAPHYOPTIONS_WHITEBALANCE"]._serialized_start = 3965
    _globals["_PHOTOGRAPHYOPTIONS_WHITEBALANCE"]._serialized_end = 4062
    _globals["_PHOTOGRAPHYOPTIONS_PREVIEW_SPORT_LEVEL"]._serialized_start = 4064
    _globals["_PHOTOGRAPHYOPTIONS_PREVIEW_SPORT_LEVEL"]._serialized_end = 4159
    _globals["_PHOTOGRAPHYOPTIONS_COLOR_MODE"]._serialized_start = 4161
    _globals["_PHOTOGRAPHYOPTIONS_COLOR_MODE"]._serialized_end = 4258
    _globals["_PHOTOGRAPHYOPTIONS_FLOW_STATE_LEVEL"]._serialized_start = 4261
    _globals["_PHOTOGRAPHYOPTIONS_FLOW_STATE_LEVEL"]._serialized_end = 4391
    _globals["_PHOTOGRAPHYOPTIONS_FLOW_STATE_LEVEL_BY_CV5"]._serialized_start = 4394
    _globals["_PHOTOGRAPHYOPTIONS_FLOW_STATE_LEVEL_BY_CV5"]._serialized_end = 4551
    _globals["_PHOTOGRAPHYOPTIONS_STARLAPSE_EXPORT_TYPE"]._serialized_start = 4553
    _globals["_PHOTOGRAPHYOPTIONS_STARLAPSE_EXPORT_TYPE"]._serialized_end = 4643
    _globals["_PHOTOGRAPHYOPTIONS_PANO_EXPOSURE_MODE"]._serialized_start = 4645
    _globals["_PHOTOGRAPHYOPTIONS_PANO_EXPOSURE_MODE"]._serialized_end = 4756
    _globals["_PHOTOGRAPHYOPTIONS_VIDEO_SELFIE_MODE"]._serialized_start = 4758
    _globals["_PHOTOGRAPHYOPTIONS_VIDEO_SELFIE_MODE"]._serialized_end = 4821
    _globals["_PHOTOGRAPHYOPTIONS_FLOWSTATEHORIZONTYPE"]._serialized_start = 4823
    _globals["_PHOTOGRAPHYOPTIONS_FLOWSTATEHORIZONTYPE"]._serialized_end = 4937
    _globals["_PHOTOGRAPHYOPTIONS_SHUTTERSPEED"]._serialized_start = 4940
    _globals["_PHOTOGRAPHYOPTIONS_SHUTTERSPEED"]._serialized_end = 5753
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_posture.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x63\x61mera_posture.proto\x12\x11insta360.messages"\xbe\x02\n\x1fNotificationCameraPostureUpdate\x12\\\n\x0e\x63\x61mera_posture\x18\x01 \x01(\x0e\x32\x44.insta360.messages.NotificationCameraPostureUpdate.CameraPostureType"\xbc\x01\n\x11\x43\x61meraPostureType\x12\x1b\n\x17\x43\x41MERA_POSTURE_ROTATE_0\x10\x00\x12\x1c\n\x18\x43\x41MERA_POSTURE_ROTATE_90\x10\x01\x12\x1d\n\x19\x43\x41MERA_POSTURE_ROTATE_180\x10\x02\x12\x1d\n\x19\x43\x41MERA_POSTURE_ROTATE_270\x10\x03\x12\x15\n\x11\x43\x41MERA_POSTURE_UP\x10\x04\x12\x17\n\x13\x43\x41MERA_POSTURE_DOWN\x10\x05\x42\x08\xa2\x02\x05INSPBb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "camera_posture_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"\242\002\005INSPB"
    _globals["_NOTIFICATIONCAMERAPOSTUREUPDATE"]._serialized_start = 44
    _globals["_NOTIFICATIONCAMERAPOSTUREUPDATE"]._serialized_end = 362
    _globals[
        "_NOTIFICATIONCAMERAPOSTUREUPDATE_CAMERAPOSTURETYPE"
    ]._serialized_start = 174
    _globals["_NOTIFICATIONCAMERAPOSTUREUPDATE_CAMERAPOSTURETYPE"]._serialized_end = 362
# @@protoc_insertion_point(module_scope)
